var group__PkgSurfaceMeshParameterizationRef =
[
    [ "Main Functions", "group__PkgSurfaceMeshParameterizationMainFunction.html", "group__PkgSurfaceMeshParameterizationMainFunction" ],
    [ "Enums", "group__PkgSurfaceMeshParameterizationEnums.html", "group__PkgSurfaceMeshParameterizationEnums" ],
    [ "Concepts", "group__PkgSurfaceMeshParameterizationConcepts.html", "group__PkgSurfaceMeshParameterizationConcepts" ],
    [ "Surface Parameterization Methods", "group__PkgSurfaceMeshParameterizationMethods.html", "group__PkgSurfaceMeshParameterizationMethods" ],
    [ "Border Parameterization Methods", "group__PkgSurfaceMeshParameterizationBorderParameterizationMethods.html", "group__PkgSurfaceMeshParameterizationBorderParameterizationMethods" ],
    [ "surface_mesh_parameterization.h", "surface__mesh__parameterization_8h.html", null ]
];